/*----------------------------------------------------------------------
  File    : LogoPanel.java
  Contents: frame class for logo panel
  Author  : Christian Borgelt
  History : 2023.05.16 file created from file dialog/LogoPanel.java
----------------------------------------------------------------------*/
package jmlp;

import java.awt.Graphics;
import java.awt.Color;
import java.awt.Dimension;
import javax.swing.JPanel;
import javax.swing.ImageIcon;

/*--------------------------------------------------------------------*/
/** Class for a logo panel (about dialog box).
 *  @author Christian Borgelt
 *  @since  2023.05.16 */
/*--------------------------------------------------------------------*/
public class LogoPanel extends JPanel {

  private static final long serialVersionUID = 0x00010002L;

  /*------------------------------------------------------------------*/
  /*  constants                                                       */
  /*------------------------------------------------------------------*/
  /** the data for the PLUS logo (GIF format) */
  private static byte[] plus = {
      71,  73,  70,  56,  57,  97,  98,   0, 102,   0,  -9,   0,
       0, 119, -91,-104,  -1,  -1,  -1, -60, -61, -60,-118,-120,
    -120,-104,-106,-105, -30, -31, -31, -23, -22, -22, -30, -29,
     -28,  -8,  -8,  -8, -15, -15, -15, -44, -43, -42, -59, -58,
     -56, -80, -79, -77, -73, -72, -70,   0,  87,  61,  35,  31,
      32,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
      -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
      -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
      -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
      -1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
       0,  33,  -7,   4,   1,   0,   0,  13,   0,  44,   0,   0,
       0,   0,  98,   0, 102,   0,  71,   8,  -1,   0,  29,   8,
      28,  72, -80, -96, -63,-125,   8,  19,  42,  92, -56, -80,
     -95, -61,-121,  16,  35,  74,-100,  72, -79, -94, -59,-117,
      24,  37,  54, -40, -56, -79, -93, -57,   6,  15,  66,-118,
     124, -48, 113, -92, -56,-113,  40,  57, 102, 116,-104, 114,
      99, -56,-106,  37,  77, -54,-100,   9, -45,  37, -55,-106,
      25,  83, -34, -84, 105, -13,  38, -51, -98,  50,  93, 122,
      52, -87,  51, 101,  68,-108,  59,  99, 126, 124,   9,-110,
     104, -45,-103,  73, 123, -22,  12, -70,  20,  37,  67, -92,
      75,  71,   2, -75, -55,-111,  42, -44, -81,  63, 121,  10,
      -3,  88,-112, 103, -44, -90,  93,  73, -98,  68,-117,  20,
     -84,  90, -73,  83,-103,-106,  20,  43, -10, -20,  80, -69,
     110, -27, -46, -67, -21, 116, -18, -34, -65, 118, -97,-122,
      77,  -6,  21, 102, -40, -69, 127,  19,  79,  53,  75,  84,
      46,  88, -58,-118,  35,  75, -50, -38,  55, 109, -27, -55,
     116,  87, 106, -34, -52, -71, -77, -25, -49,  24,  49, 103,
       6,  13, -79, -26,  90, -47, 109,   3, -85, -20, -36,  82,
     117, -52,-105,  52,  27,  31,  54,-116, 115,  98, -37, -44,
      82, 101,  67,   5, -70,  86, -81, -32, -45,  74, -55,  54,
     -60, -54,-105, -85,  96, -53, -67, -13,  42, -33,  61, -44,
     -86,  66, -30, -81, 125,  74, 119, -20, 117,  57, -45, -64,
      84,  -3, 122,  44, 107, -74,  46, -16, -33,  90, -63,  95,
      -1, -73, 126,  25,  36, -22, -32, 124, -55,-121, -49,  46,
     -38,  -9,  -7, -86, 113, 117,  83,  87, -33,  -6,  -3,  -7,
     -17, -10, -39, -26, -33, -49, -65, -65,  81, -46,   0,   6,
      40, -32,-128,   4,  22, 104, -32,-127,   8,  30,  -8,  94,
    -126, -74,  -7,  87,  19,-125,   3, 121, -25,  30,  96,  -8,
      57,  23, -96,  97, -82, -15,  55, -31, 106,-100,  45, -58,
    -104, 122,  21, 122,  40, -36,  69,  34,  98,   8,  91,  80,
     -42, -63,-105, -43, 127,  26,  65,-105,  30, 114, -68, -55,
     -89,-107,  94, -52,  33,  54, -30, 112,  46, -90,-123,  24,
    -118,-123, 109,-123, -36,  78, -20, -23, 120,  99,  66, -73,
     -39, -56, -37,-113, -45, -47, -89,  92,-114,  27,  93, 101,
     -92, 101,  92, -99,  52,  95, 114,  32, -42,  88, -33,-112,
     -36,  53,  -9,  98,-116,-124,  57,-107, -30,  83,  24,-102,
     -89, -27, 118,   4, 117,  87,  28,  91,  82,  38,  57,  30,
    -120, -83,-107,-105, -95, 119,  42,-118,-121, -41,-110, 114,
      46, -57, 100, 100,  27, -90, 102, -89,-100,  72, -62,  21,
     103, 123, -86,  85,  57,  99,-112,  31, -82, -88, -95, -98,
      74,  18,-102,  94, -98, 121, -66, -73,  97,-113, -47, -51,
     -10, -40, -99,  14, -22,-121, 104,-112, 123,-106,  88, -87,
     105, 111, -26, -41, -24, -90,  20, 118, -54, -87, -88, -96,
    -106, 106, -86,-123,  16, -90, -86, -22, -86, -84, -74, -22,
     -22, -85, -80, -58,  -1,  42, -21, -84, -76, -42, 106, -21,
      74,-118, -35, -22,  36, 127, -70, -98, -38,   0, -84,-110,
      89,  -7,-105, -86, 116,-123,  87, 108,-120,  88,  10,  88,
     -88, 125, -56, 114,   8, -96,-119, -96,  54,  75,  90,-104,
     -57,  -6,   9,  89, 109,-101, -75,  41,  33,-101, 112, -78,
      24,  90,  81,  31, -66,  69, -33, -79, -34,  86, -92, 105,
      92,  49,  -2, -58, -27, -89,  93,-107, 123,  84,-111, -31,
    -118,  87,  39, 123, -58,  62, -39,  81,-125,-122, -58, -53,
      39,-105, -15,-123,  24,  88,-117,  99,  46, -86, -26, -68,
     117,-118, -39,  39,  94, -18,  62,  -9, -89,  84,  58, 122,
     -55, -36,  96,  62,  69, 122, -25,  67, -16,  10, -87,  84,
     117,  86,   2, -55,  48, -65,  11,  -1,-118,  99, -64, -58,
     -39,-120, 113,-113,-104,  66, 106, -15, -67,  11,  49, 121,
     -38,  79,  44,  11,  74, -89, 118,  40,  43,-116,  30,-108,
     104, -82,  55, -78, -53, -62,  90, -38, -92, -52,  48, -45,
     -20,  48,-110, -21,-114,  91,  23, -86,   6, -87, 108,  51,
    -112,  72,  31, -99, -41,-111,-119, -39, -59, 115, -69,  91,
     102, -20, -16, -98,-113, -70,  73, -76,-103, -47,  25,  55,
      53,-107, -28,-103,-120,  31, -87,  87, -66, -90, -75, 116,
      76, -29, -36, -26, -41, -88, -99,  69,  35,-107,-105, -58,
     -10,  50, 120,  29,  55, -83, -74, -64, 109,  23, 102, -74,
     -67, -63,  86,  -5, -27, -61,  85, -58, 107,-115, 103, -80,
      75,  51,  45, 112, -50, -20, -18, -27,  90, -67, 123,-109,
     109, 120,-123,  96,  15,  93, 119, -30, -27,  97, -35, -77,
     -93,-113, -37,  57,  91, -66, -76,  -7,-121,  29,-101,  57,
      71, 122,  -8, -90,  85,  19, 110,  50, 101, -11, -98,  92,
     105, -96, -99, -49, 107, -83, -33,-102, -93,  30, -72, -22,
    -118,-122, -20, -85, -50, -92,  67,  60, -87, -74, -77,  87,
     124, -74, -38,-111,  99, -98,  59, -70, -96,  23,  -2,  -5,
     -52,-114,  54,  62, -68, -98,-118,-107, 126, -68,-122, -93,
      47, -17,  -4, -13, -48,  31,  31,  16,   0,  59, };

  /*------------------------------------------------------------------*/
  /*  instance variables                                              */
  /*------------------------------------------------------------------*/
  /** the icon to display */
  private ImageIcon logo;

  /*------------------------------------------------------------------*/
  /** Create a logo panel
   *  @since  2023.05.16 (Christian Borgelt) */
  /*------------------------------------------------------------------*/

  public LogoPanel ()
  { this.logo = new ImageIcon(plus); }

  /*------------------------------------------------------------------*/
  /** Get the preferred size of the logo panel.
   *  @return the preferred size of the logo panel
   *  @since  2023.05.16 (Christian Borgelt) */
  /*------------------------------------------------------------------*/

  public Dimension getPreferredSize ()
  { return new Dimension(this.logo.getIconWidth(),
                         this.logo.getIconHeight()); }

  /*------------------------------------------------------------------*/
  /** Draw the logo panel.
   *  @param  g the graphics to use for drawing
   *  @since  2023.05.16 (Christian Borgelt) */
  /*------------------------------------------------------------------*/

  public void paint (Graphics g)
  {                             /* --- draw the logo */
    g.setColor(new Color(0xef, 0xef, 0xef));
    g.fillRect(0, 0, logo.getIconWidth(), logo.getIconHeight());
    g.drawImage(logo.getImage(), 0, 0, this);
  }  /* paint() */              /* draw the logo */

}  /* class LogoPanel */
